@@ -152,7 +152,7 @@
 #' year <- eusilc[, unique(year)]
 #' year <- year[-1]
 #' leaf_out <- c()
-#' for(y in year){
+#' for(y in year) {
 #'   split.person <- eusilc[
 #'     year == (y-1) & !duplicated(hid) & !(hid %in% leaf_out),
 #'     sample(pid, 20)
@@ -189,8 +189,7 @@ draw.bootstrap <- function(
   cluster = NULL, totals = NULL, single.PSU = c("merge", "mean"), boot.names =
     NULL, split = FALSE, pid = NULL, new.method = FALSE) {
 
-  occurence_first_period <- STRATA_VAR_HELP <- fpc <- ssd_hid <-
-    ssd_period <- NULL
+  occurence_first_period <- NULL
 
   ##########################################################
   # INPUT CHECKING
@@ -203,6 +202,7 @@ draw.bootstrap <- function(
 
   c.names <- colnames(dat)
 
+  removeCols <- c()
   # check REP
   if (length(REP) != 1) {
     stop("REP must have length 1")
@@ -215,9 +215,11 @@ draw.bootstrap <- function(
   }
 
   # check hid
-  if (is.null(hid)) {
-    dat[, ssd_hid := 1:.N]
-    hid <- "ssd_hid"
+  hidNULL <- is.null(hid)
+  if (hidNULL) {
+    hid <- generateRandomName(20, colnames(dat))
+    dat[, c(hid) := 1:.N]
+    removeCols <- c(removeCols, hid)
   }
 
   if (length(hid) != 1) {
@@ -239,9 +241,11 @@ draw.bootstrap <- function(
   }
 
   # check period
-  if (is.null(period)) {
-    dat[, ssd_period := 1]
-    period <- "ssd_period"
+  periodNULL <- is.null(period)
+  if (periodNULL) {
+    period <- generateRandomName(20, colnames(dat))
+    dat[, c(period) := 1]
+    removeCols <- c(removeCols, period)
   }
 
   if (length(period) != 1) {
@@ -286,7 +290,7 @@ draw.bootstrap <- function(
   spec.variables <- c(hid, weights, period, strata, cluster, totals, pid)
   spec.variables <- spec.variables[!spec.variables %in% c("1", "I")]
   dat.na <- dat[, mget(spec.variables)]
-  dat.na <- sapply(dat.na, function(z){
+  dat.na <- sapply(dat.na, function(z) {
     any(is.na(z))
   })
   if (any(dat.na)) {
@@ -307,10 +311,13 @@ draw.bootstrap <- function(
         stop("When defining multiple strata variables for single stage",
              " sampling design\n none of them can be '1' or 'I'.")
       }
-
-      dt.eval("dat[,STRATA_VAR_HELP:=paste(", paste0(strata, collapse = ","),
+      strata_var_help <- generateRandomName(20, colnames(dat))
+      dat[, c(strata_var_help) := do.call(paste, c(.SD, sep = "-")), ]
+      dt.eval("dat[,", strata_var_help, ":=paste(",
+              paste0(strata, collapse = ","),
               ",sep='-')]")
-      strata <- "STRATA_VAR_HELP"
+      strata <- strata_var_help
+      removeCols <- c(removeCols, strata)
     }
   }
 
@@ -369,16 +376,17 @@ draw.bootstrap <- function(
     if (length(cluster) == 1) {
       # if no clusters are specified calculate number of households in each
       #   strata
-      totals <- "fpc"
+      totals <- generateRandomName(20, existingNames = colnames(dat))
       fpc.strata <- strata[!strata %in% c("I", "1")] # nolint
-      dt.eval("dat[,fpc:=sum(", weights, "[!duplicated(",
+      dt.eval("dat[,", totals, ":=sum(", weights, "[!duplicated(",
               hid, ")]),by=c(fpc.strata,period)]")
+      removeCols <- c(removeCols, totals)
     } else {
 
       stop("For multistage sampling the number of PSUs at each level needs to ",
            "be specified!")
     }
-    add.totals <- TRUE
+
   } else {
 
     if (length(totals) != length(strata)) {
@@ -390,9 +398,6 @@ draw.bootstrap <- function(
     if (!any(unlist(dat[, lapply(.SD, is.numeric), .SDcols = c(totals)]))) {
       stop("Not all elements in totals are numeric columns in dat")
     }
-
-    add.totals <- FALSE
-
   }
   ##########################################################
 
@@ -435,14 +440,16 @@ draw.bootstrap <- function(
     dt.eval("dat[,", hid, ":=", paste0(hid, "_orig"), "]")
     dat[, c(paste0(hid, "_orig")) := NULL]
   }
-  if (add.totals) {
-    dt.eval("dat[,", totals, ":=NULL]")
+  if (length(removeCols) > 0) {
+    dat[, c(removeCols) := NULL]
   }
-  if ("STRATA_VAR_HELP" %in% colnames(dat)) {
-    dat[, STRATA_VAR_HELP := NULL]
+
+
+  if (periodNULL) {
+    period <- NULL
   }
-  if ("fpc" %in% colnames(dat)) {
-    dat[, fpc := NULL]
+  if (hidNULL) {
+    hid <- NULL
   }
 
   setattr(dat, "weights", weights)
